@@ -112,8 +112,9 @@ def save_model(
                       .. code-block:: python
 
                         from mlflow.models.signature import infer_signature
+
                         train = df.drop_column("target_label")
-                        predictions = ... # compute model predictions
+                        predictions = ...  # compute model predictions
                         signature = infer_signature(train, predictions)
     :param input_example: Input example provides one or several instances of valid
                           model input. The example can be used as a hint of what data to feed the
@@ -142,10 +143,10 @@ def save_model(
         # Start MLflow session and save model to current working directory
         with mlflow.start_run():
             model.fit(epochs, learning_rate)
-            mlflow.fastai.save_model(model, 'model')
+            mlflow.fastai.save_model(model, "model")
 
         # Load saved model for inference
-        model_uri = "{}/{}".format(os.getcwd(), 'model')
+        model_uri = "{}/{}".format(os.getcwd(), "model")
         loaded_model = mlflow.fastai.load_model(model_uri)
         results = loaded_model.predict(predict_data)
     """
@@ -267,8 +268,9 @@ def log_model(
                       .. code-block:: python
 
                         from mlflow.models.signature import infer_signature
+
                         train = df.drop_column("target_label")
-                        predictions = ... # compute model predictions
+                        predictions = ...  # compute model predictions
                         signature = infer_signature(train, predictions)
     :param input_example: Input example provides one or several instances of valid
                           model input. The example can be used as a hint of what data to feed the
@@ -296,25 +298,31 @@ def log_model(
         import mlflow.fastai
         from mlflow import MlflowClient
 
+
         def main(epochs=5, learning_rate=0.01):
             # Download and untar the MNIST data set
             path = vis.untar_data(vis.URLs.MNIST_SAMPLE)
 
-           # Prepare, transform, and normalize the data
-           data = vis.ImageDataBunch.from_folder(path, ds_tfms=(vis.rand_pad(2, 28), []), bs=64)
-           data.normalize(vis.imagenet_stats)
+            # Prepare, transform, and normalize the data
+            data = vis.ImageDataBunch.from_folder(
+                path, ds_tfms=(vis.rand_pad(2, 28), []), bs=64
+            )
+            data.normalize(vis.imagenet_stats)
 
-           # Create the CNN Learner model
-           model = vis.cnn_learner(data, vis.models.resnet18, metrics=vis.accuracy)
+            # Create the CNN Learner model
+            model = vis.cnn_learner(data, vis.models.resnet18, metrics=vis.accuracy)
 
-           # Start MLflow session and log model
-           with mlflow.start_run() as run:
+            # Start MLflow session and log model
+            with mlflow.start_run() as run:
                 model.fit(epochs, learning_rate)
-                mlflow.fastai.log_model(model, 'model')
+                mlflow.fastai.log_model(model, "model")
+
+            # fetch the logged model artifacts
+            artifacts = [
+                f.path for f in MlflowClient().list_artifacts(run.info.run_id, "model")
+            ]
+            print("artifacts: {}".format(artifacts))
 
-           # fetch the logged model artifacts
-           artifacts = [f.path for f in MlflowClient().list_artifacts(run.info.run_id, 'model')]
-           print("artifacts: {}".format(artifacts))
 
         main()
 
@@ -458,6 +466,7 @@ def autolog(
         import mlflow.fastai
         from mlflow import MlflowClient
 
+
         def print_auto_logged_info(r):
             tags = {k: v for k, v in r.data.tags.items() if not k.startswith("mlflow.")}
             artifacts = [f.path for f in MlflowClient().list_artifacts(r.info.run_id, "model")]
@@ -467,12 +476,15 @@ def autolog(
             print("metrics: {}".format(r.data.metrics))
             print("tags: {}".format(tags))
 
+
         def main(epochs=5, learning_rate=0.01):
             # Download and untar the MNIST data set
             path = vis.untar_data(vis.URLs.MNIST_SAMPLE)
 
             # Prepare, transform, and normalize the data
-            data = vis.ImageDataBunch.from_folder(path, ds_tfms=(vis.rand_pad(2, 28), []), bs=64)
+            data = vis.ImageDataBunch.from_folder(
+                path, ds_tfms=(vis.rand_pad(2, 28), []), bs=64
+            )
             data.normalize(vis.imagenet_stats)
 
             # Create CNN the Learner model
@@ -488,6 +500,7 @@ def autolog(
             # fetch the auto logged parameters, metrics, and artifacts
             print_auto_logged_info(mlflow.get_run(run_id=run.info.run_id))
 
+
         main()
 
     .. code-block:: text
@@ -586,7 +599,6 @@ def autolog(
 
         run_id = mlflow.active_run().info.run_id
         with batch_metrics_logger(run_id) as metrics_logger:
-
             if not fit_in_fine_tune:
                 early_stop_callback = _find_callback_of_type(EarlyStoppingCallback, self.cbs)
                 _log_early_stop_callback_params(early_stop_callback)
