@@ -375,13 +375,13 @@ def _enforce_mlflow_datatype(name, values: pd.Series, t: DataType):
         # NB: datetime values have variable precision denoted by brackets, e.g. datetime64[ns]
         # denotes nanosecond precision. Since MLflow datetime type is precision agnostic, we
         # ignore precision when matching datetime columns.
-        return values
+        return values.astype(np.dtype("datetime64[ns]"))
 
     if t == DataType.datetime and values.dtype == object:
         # NB: Pyspark date columns get converted to object when converted to a pandas
         # DataFrame. To respect the original typing, we convert the column to datetime.
         try:
-            return values.astype(np.datetime64, errors="raise")
+            return values.astype(np.dtype("datetime64[ns]"), errors="raise")
         except ValueError as e:
             raise MlflowException(
                 "Failed to convert column {} from type {} to {}.".format(name, values.dtype, t)
@@ -740,11 +740,11 @@ def add_libraries_to_model(model_uri, run_id=None, registered_model_name=None):
         from mlflow.models.signature import infer_signature
 
         with mlflow.start_run():
-          iris = datasets.load_iris()
-          iris_train = pd.DataFrame(iris.data, columns=iris.feature_names)
-          clf = RandomForestClassifier(max_depth=7, random_state=0)
-          clf.fit(iris_train, iris.target)
-          mlflow.sklearn.log_model(clf, "iris_rf", registered_model_name="model-with-libs")
+            iris = datasets.load_iris()
+            iris_train = pd.DataFrame(iris.data, columns=iris.feature_names)
+            clf = RandomForestClassifier(max_depth=7, random_state=0)
+            clf.fit(iris_train, iris.target)
+            mlflow.sklearn.log_model(clf, "iris_rf", registered_model_name="model-with-libs")
 
         # model uri for the above model
         model_uri = "models:/model-with-libs/1"
