@@ -107,7 +107,7 @@ def save_model(
                       column omitted) and valid model output (e.g. model predictions generated on
                       the training dataset), for example:
 
-                      .. code-block:: py
+                      .. code-block:: python
 
                         from mlflow.models.signature import infer_signature
 
@@ -233,7 +233,7 @@ def log_model(
                       column omitted) and valid model output (e.g. model predictions generated on
                       the training dataset), for example:
 
-                      .. code-block:: py
+                      .. code-block:: python
 
                         from mlflow.models.signature import infer_signature
 
@@ -316,20 +316,17 @@ def load_model(model_uri, dst_path=None):
 
 
 def _save_model(model, path):
-
     with open(path, "wb") as f:
         pickle.dump(model, f)
 
 
 def _load_model(path):
-
     with open(path, "rb") as pickled_model:
         model = pickle.load(pickled_model)
     return model
 
 
 def _load_pyfunc(path):
-
     return _PmdarimaModelWrapper(_load_model(path))
 
 
@@ -341,7 +338,6 @@ class _PmdarimaModelWrapper:
         self._pmdarima_version = pmdarima.__version__
 
     def predict(self, dataframe) -> pd.DataFrame:
-
         df_schema = dataframe.columns.values.tolist()
 
         if len(dataframe) > 1:
@@ -356,7 +352,7 @@ class _PmdarimaModelWrapper:
 
         if not n_periods:
             raise MlflowException(
-                f"The provided prediction configuration pd.DataFrame columns ({df_schema}) do not"
+                f"The provided prediction configuration pd.DataFrame columns ({df_schema}) do not "
                 "contain the required column `n_periods` for specifying future prediction periods "
                 "to generate.",
                 error_code=INVALID_PARAMETER_VALUE,
