@@ -15,13 +15,16 @@ import warnings
 
 import numpy as np
 import pandas as pd
+from functools import partial
 from packaging.version import Version
 import posixpath
 
 import mlflow
 import shutil
 from mlflow import pyfunc
+from mlflow.environment_variables import MLFLOW_DEFAULT_PREDICTION_DEVICE
 from mlflow.exceptions import MlflowException
+from mlflow.ml_package_versions import _ML_PACKAGE_VERSIONS
 from mlflow.models import Model, ModelSignature
 from mlflow.models.model import MLMODEL_FILE_NAME
 from mlflow.models.utils import ModelInputExample, _save_example
@@ -61,9 +64,14 @@ _TORCH_STATE_DICT_FILE_NAME = "state_dict.pth"
 _PICKLE_MODULE_INFO_FILE_NAME = "pickle_module_info.txt"
 _EXTRA_FILES_KEY = "extra_files"
 _REQUIREMENTS_FILE_KEY = "requirements_file"
+_TORCH_CPU_DEVICE_NAME = "cpu"
+_TORCH_DEFAULT_GPU_DEVICE_NAME = "cuda"
 
 _logger = logging.getLogger(__name__)
 
+MIN_REQ_VERSION = Version(_ML_PACKAGE_VERSIONS["pytorch-lightning"]["autologging"]["minimum"])
+MAX_REQ_VERSION = Version(_ML_PACKAGE_VERSIONS["pytorch-lightning"]["autologging"]["maximum"])
+
 
 def get_default_pip_requirements():
     """
@@ -184,8 +192,9 @@ def log_model(
                       .. code-block:: python
 
                         from mlflow.models.signature import infer_signature
+
                         train = df.drop_column("target_label")
-                        predictions = ... # compute model predictions
+                        predictions = ...  # compute model predictions
                         signature = infer_signature(train, predictions)
     :param input_example: Input example provides one or several instances of valid
                           model input. The example can be used as a hint of what data to feed the
@@ -241,6 +250,7 @@ def log_model(
         import torch
         import mlflow.pytorch
 
+
         class LinearNNModel(torch.nn.Module):
             def __init__(self):
                 super().__init__()
@@ -250,6 +260,7 @@ def log_model(
                 y_pred = self.linear(x)
                 return y_pred
 
+
         def gen_data():
             # Example linear model modified to use y = 2x
             # from https://github.com/hunkim/PyTorchZeroToAll
@@ -258,6 +269,7 @@ def log_model(
             y = torch.from_numpy(np.array([x * 2 for x in X])).view(-1, 1)
             return X, y
 
+
         # Define model, loss, and optimizer
         model = LinearNNModel()
         criterion = torch.nn.MSELoss()
@@ -289,8 +301,9 @@ def log_model(
         # Fetch the logged model artifacts
         print("run_id: {}".format(run.info.run_id))
         for artifact_path in ["model/data", "scripted_model/data"]:
-            artifacts = [f.path for f in MlflowClient().list_artifacts(run.info.run_id,
-                        artifact_path)]
+            artifacts = [
+                f.path for f in MlflowClient().list_artifacts(run.info.run_id, artifact_path)
+            ]
             print("artifacts: {}".format(artifacts))
 
     .. code-block:: text
@@ -383,8 +396,9 @@ def save_model(
                       .. code-block:: python
 
                         from mlflow.models.signature import infer_signature
+
                         train = df.drop_column("target_label")
-                        predictions = ... # compute model predictions
+                        predictions = ...  # compute model predictions
                         signature = infer_signature(train, predictions)
     :param input_example: Input example provides one or several instances of valid
                           model input. The example can be used as a hint of what data to feed the
@@ -435,10 +449,12 @@ def save_model(
         import torch
         import mlflow.pytorch
 
+
         # Class defined here
         class LinearNNModel(torch.nn.Module):
             ...
 
+
         # Initialize our model, criterion and optimizer
         ...
 
@@ -543,7 +559,6 @@ def save_model(
             )
 
     if requirements_file:
-
         warnings.warn(
             "`requirements_file` has been deprecated. Please use `pip_requirements` instead.",
             FutureWarning,
@@ -692,10 +707,12 @@ def load_model(model_uri, dst_path=None, **kwargs):
         import torch
         import mlflow.pytorch
 
+
         # Class defined here
         class LinearNNModel(torch.nn.Module):
             ...
 
+
         # Initialize our model, criterion and optimizer
         ...
 
@@ -755,9 +772,20 @@ class _PyTorchWrapper:
     def __init__(self, pytorch_model):
         self.pytorch_model = pytorch_model
 
-    def predict(self, data, device="cpu"):
+    def predict(self, data, device=None):
         import torch
 
+        # if CUDA is available, we use the default CUDA device.
+        # To force inference to the CPU when the GPU is available, please set
+        # MLFLOW_DEFAULT_PREDICTION_DEVICE to "cpu"
+        # If a specific non-default device is passed in, we continue to respect that.
+        if device is None:
+            if MLFLOW_DEFAULT_PREDICTION_DEVICE.get():
+                device = MLFLOW_DEFAULT_PREDICTION_DEVICE.get()
+            elif torch.cuda.is_available():
+                device = _TORCH_DEFAULT_GPU_DEVICE_NAME
+            else:
+                device = _TORCH_CPU_DEVICE_NAME
         if isinstance(data, pd.DataFrame):
             inp_data = data.values.astype(np.float32)
         elif isinstance(data, np.ndarray):
@@ -775,6 +803,10 @@ class _PyTorchWrapper:
         with torch.no_grad():
             input_tensor = torch.from_numpy(inp_data).to(device)
             preds = self.pytorch_model(input_tensor)
+            # if the predictions happened on a remote device, copy them back to
+            # the host CPU for processing
+            if device != _TORCH_CPU_DEVICE_NAME:
+                preds = preds.to(_TORCH_CPU_DEVICE_NAME)
             if not isinstance(preds, torch.Tensor):
                 raise TypeError(
                     "Expected PyTorch model to output a single output tensor, "
@@ -908,13 +940,19 @@ def autolog(
     <https://github.com/mlflow/mlflow/tree/master/examples/pytorch/MNIST>`_ for
     an expansive example with implementation of additional lightening steps.
 
-    **Note**: Autologging is only supported for PyTorch Lightning models,
+    **Note**: Full autologging is only supported for PyTorch Lightning models,
     i.e., models that subclass
     `pytorch_lightning.LightningModule \
     <https://pytorch-lightning.readthedocs.io/en/latest/lightning_module.html>`_.
-    In particular, autologging support for vanilla PyTorch models that only subclass
-    `torch.nn.Module <https://pytorch.org/docs/stable/generated/torch.nn.Module.html>`_
-    is not yet available.
+    Autologging support for vanilla PyTorch (ie models that only subclass
+    `torch.nn.Module <https://pytorch.org/docs/stable/generated/torch.nn.Module.html>`_)
+    only autologs calls to
+    `torch.utils.tensorboard.SummaryWriter <https://pytorch.org/docs/stable/tensorboard.html>`_'s
+    ``add_scalar`` and ``add_hparams`` methods to mlflow. In this case, there's also
+    no notion of an "epoch".
+
+    .. Note:: Only pytorch-lightning modules between versions MIN_REQ_VERSION and
+              MAX_REQ_VERSION are known to be compatible with mlflow's autologging.
 
     :param log_every_n_epoch: If specified, logs metrics once every `n` epochs. By default, metrics
                        are logged after every epoch.
@@ -962,6 +1000,7 @@ def autolog(
         # loop step, (no validation, no testing). It illustrates how you can use MLflow
         # to auto log parameters, metrics, and models.
 
+
         class MNISTModel(pl.LightningModule):
             def __init__(self):
                 super().__init__()
@@ -985,8 +1024,8 @@ def autolog(
             def configure_optimizers(self):
                 return torch.optim.Adam(self.parameters(), lr=0.02)
 
-        def print_auto_logged_info(r):
 
+        def print_auto_logged_info(r):
             tags = {k: v for k, v in r.data.tags.items() if not k.startswith("mlflow.")}
             artifacts = [f.path for f in MlflowClient().list_artifacts(r.info.run_id, "model")]
             print("run_id: {}".format(r.info.run_id))
@@ -995,12 +1034,14 @@ def autolog(
             print("metrics: {}".format(r.data.metrics))
             print("tags: {}".format(tags))
 
+
         # Initialize our model
         mnist_model = MNISTModel()
 
         # Initialize DataLoader from MNIST Dataset
-        train_ds = MNIST(os.getcwd(), train=True,
-            download=True, transform=transforms.ToTensor())
+        train_ds = MNIST(
+            os.getcwd(), train=True, download=True, transform=transforms.ToTensor()
+        )
         train_loader = DataLoader(train_ds, batch_size=32)
 
         # Initialize a trainer
@@ -1040,7 +1081,55 @@ def autolog(
 
         PyTorch autologged MLflow entities
     """
-    import pytorch_lightning as pl
-    from mlflow.pytorch._pytorch_autolog import patched_fit
+    import atexit
 
-    safe_patch(FLAVOR_NAME, pl.Trainer, "fit", patched_fit, manage_run=True)
+    try:
+        import pytorch_lightning as pl
+    except ImportError:
+        pass
+    else:
+        from mlflow.pytorch._lightning_autolog import patched_fit
+
+        safe_patch(FLAVOR_NAME, pl.Trainer, "fit", patched_fit, manage_run=True)
+
+    try:
+        import torch.utils.tensorboard.writer
+    except ImportError:
+        pass
+    else:
+        from mlflow.pytorch._pytorch_autolog import (
+            patched_add_event,
+            patched_add_hparams,
+            patched_add_summary,
+            _flush_queue,
+        )
+
+        safe_patch(
+            FLAVOR_NAME,
+            torch.utils.tensorboard.writer.FileWriter,
+            "add_event",
+            partial(patched_add_event, mlflow_log_every_n_step=log_every_n_step),
+            manage_run=True,
+        )
+        safe_patch(
+            FLAVOR_NAME,
+            torch.utils.tensorboard.writer.FileWriter,
+            "add_summary",
+            patched_add_summary,
+            manage_run=True,
+        )
+        safe_patch(
+            FLAVOR_NAME,
+            torch.utils.tensorboard.SummaryWriter,
+            "add_hparams",
+            patched_add_hparams,
+            manage_run=True,
+        )
+
+        atexit.register(_flush_queue)
+
+
+if autolog.__doc__ is not None:
+    autolog.__doc__ = autolog.__doc__.replace("MIN_REQ_VERSION", str(MIN_REQ_VERSION)).replace(
+        "MAX_REQ_VERSION", str(MAX_REQ_VERSION)
+    )
