@@ -69,7 +69,6 @@ _logger = logging.getLogger(__name__)
 
 
 class TrainStep(BaseStep):
-
     MODEL_ARTIFACT_RELATIVE_PATH = "model"
     SKLEARN_MODEL_ARTIFACT_RELATIVE_PATH = "sk_model"
     PREDICTED_TRAINING_DATA_RELATIVE_PATH = "predicted_training_data.parquet"
@@ -225,6 +224,54 @@ class TrainStep(BaseStep):
         else:
             return tuning_param == logged_param
 
+    def _fitted_estimator(self, *args):
+        if "calibrate_proba" in self.step_config:
+            return self._calibrated_classifier_fitted_estimator(*args)
+        else:
+            return self._label_encoded_fitted_estimator(*args)
+
+    def _calibrated_classifier_fitted_estimator(self, estimator, X_train, y_train):
+        original_estimator = estimator.fit(X_train, y_train)
+        if "classification" in self.recipe:
+            from sklearn.calibration import CalibratedClassifierCV
+
+            estimator = CalibratedClassifierCV(
+                estimator, method=self.step_config["calibrate_proba"]
+            )
+            estimator.fit(X_train, y_train)
+
+        return estimator, {"original_estimator": original_estimator}
+
+    def _label_encoded_fitted_estimator(self, estimator, X_train, y_train):
+        from sklearn.preprocessing import LabelEncoder
+
+        label_encoder = None
+        target_column_class_labels = None
+        encoded_y_train = y_train
+        if "classification" in self.recipe:
+            label_encoder = LabelEncoder()
+            label_encoder.fit(y_train)
+            target_column_class_labels = label_encoder.classes_
+            import pandas as pd
+
+            encoded_y_train = pd.Series(label_encoder.transform(y_train))
+
+        def inverse_label_encoder(predicted_output):
+            if not label_encoder:
+                return predicted_output
+
+            return label_encoder.inverse_transform(predicted_output)
+
+        estimator.fit(X_train, encoded_y_train)
+        original_predict = estimator.predict
+
+        def wrapped_predict(*args, **kwargs):
+            return inverse_label_encoder(original_predict(*args, **kwargs))
+
+        estimator.predict = wrapped_predict
+
+        return estimator, {"target_column_class_labels": target_column_class_labels}
+
     def _run(self, output_directory):
         def my_warn(*args, **kwargs):
             timestamp = datetime.datetime.now().strftime("%Y/%m/%d %H:%M:%S")
@@ -319,15 +366,17 @@ class TrainStep(BaseStep):
                 ),
             }
 
+            run_name = self.tracking_config.run_name
             best_estimator_params = None
             mlflow.autolog(log_models=False, silent=True)
-            with mlflow.start_run(tags=tags) as run:
+            with mlflow.start_run(run_name=run_name, tags=tags) as run:
                 estimator = self._resolve_estimator(
                     X_train, y_train, validation_df, run, output_directory
                 )
-                estimator.fit(X_train, y_train)
-
-                logged_estimator = self._log_estimator_to_mlflow(estimator, X_train)
+                fitted_estimator, additional_fitted_args = self._fitted_estimator(
+                    estimator, X_train, y_train
+                )
+                logged_estimator = self._log_estimator_to_mlflow(fitted_estimator, X_train)
 
                 # Create a recipe consisting of the transformer+model for test data evaluation
                 with open(transformer_path, "rb") as f:
@@ -336,12 +385,16 @@ class TrainStep(BaseStep):
                     transformer, "transform/transformer", code_paths=self.code_paths
                 )
 
-                trained_pipeline = make_pipeline(transformer, estimator)
+                trained_pipeline = make_pipeline(transformer, fitted_estimator)
                 # Creating a wrapped recipe model which exposes a single predict function
                 # so it can output both predict and predict_proba(for a classification problem)
                 # at the same time.
                 wrapped_model = WrappedRecipeModel(
-                    self.predict_scores_for_all_classes, self.predict_prefix
+                    self.predict_scores_for_all_classes,
+                    self.predict_prefix,
+                    target_column_class_labels=additional_fitted_args.get(
+                        "target_column_class_labels"
+                    ),
                 )
 
                 model_uri = get_step_output_path(
@@ -391,10 +444,21 @@ class TrainStep(BaseStep):
                 model = mlflow.pyfunc.load_model(model_uri)
                 # Adding a sklearn flavor to the pyfunc model so models could be loaded easily
                 # using mlflow.sklearn.load_model
-                model_info = Model.load(model_uri)
+                tmp_model_info = Model.load(model_uri)
                 model_data_subpath = os.path.join(
                     "artifacts", TrainStep.SKLEARN_MODEL_ARTIFACT_RELATIVE_PATH, "model.pkl"
                 )
+                model_info = Model(
+                    artifact_path="train/model",
+                    run_id=run.info.run_id,
+                    utc_time_created=tmp_model_info.utc_time_created,
+                    flavors=tmp_model_info.flavors,
+                    signature=tmp_model_info.signature,  # ModelSignature
+                    saved_input_example_info=tmp_model_info.saved_input_example_info,
+                    model_uuid=tmp_model_info.model_uuid,
+                    mlflow_version=tmp_model_info.mlflow_version,
+                    metadata=tmp_model_info.metadata,
+                )
                 model_info.add_flavor(
                     mlflow.sklearn.FLAVOR_NAME,
                     pickled_model=model_data_subpath,
@@ -442,24 +506,29 @@ class TrainStep(BaseStep):
             target_data = raw_validation_df[self.target_col]
             prediction_result = model.predict(raw_validation_df.drop(self.target_col, axis=1))
 
-            use_predict_proba = isinstance(prediction_result, pd.DataFrame)
-            if use_predict_proba and {
+            use_probability_for_error_rate = False
+            if isinstance(prediction_result, pd.DataFrame) and {
                 f"{self.predict_prefix}label",
                 f"{self.predict_prefix}score",
             }.issubset(prediction_result.columns):
-                prediction_result_for_error = (
-                    prediction_result.drop(
-                        [f"{self.predict_prefix}label", f"{self.predict_prefix}score"], axis=1
-                    )
-                    .iloc[0:]
-                    .values
-                )
+                if self.positive_class:
+                    prediction_result_for_error = prediction_result[
+                        f"{self.predict_prefix}score_{self.positive_class}"
+                    ].values
+                    # use_probability_for_error_rate to true to compute error function
+                    # based on positive class
+                    use_probability_for_error_rate = True
+                else:
+                    prediction_result_for_error = prediction_result[
+                        f"{self.predict_prefix}score"
+                    ].values
+
                 prediction_result = prediction_result[f"{self.predict_prefix}label"].values
             else:
                 prediction_result_for_error = prediction_result
             error_fn = _get_error_fn(
                 self.recipe,
-                use_probability=use_predict_proba,
+                use_probability=use_probability_for_error_rate,
                 positive_class=self.positive_class,
             )
             pred_and_error_df = pd.DataFrame(
@@ -469,28 +538,44 @@ class TrainStep(BaseStep):
                     "error": error_fn(prediction_result_for_error, target_data.to_numpy()),
                 }
             )
+            calibrated_plot = None
             train_predictions = model.predict(raw_train_df.drop(self.target_col, axis=1))
             if isinstance(train_predictions, pd.DataFrame) and {
                 f"{self.predict_prefix}label",
                 f"{self.predict_prefix}score",
             }.issubset(train_predictions.columns):
-                train_predicted_result = model.predict(raw_train_df.drop(self.target_col, axis=1))
-                train_predicted_probs = train_predicted_result.drop(
-                    [f"{self.predict_prefix}label", f"{self.predict_prefix}score"], axis=1
-                )
                 predicted_training_data = raw_train_df.assign(
                     predicted_data=train_predictions[f"{self.predict_prefix}label"],
-                    predicted_probability=train_predicted_probs.iloc[0:, 0].values,
-                )
-                worst_examples_df = BaseStep._generate_worst_examples_dataframe(
-                    raw_train_df,
-                    train_predicted_probs.iloc[0:, 0].values,
-                    error_fn(
-                        train_predicted_probs.values,
-                        raw_train_df[self.target_col].to_numpy(),
-                    ),
-                    self.target_col,
+                    predicted_score=train_predictions[f"{self.predict_prefix}score"].values,
                 )
+                if self.positive_class:
+                    worst_examples_df = BaseStep._generate_worst_examples_dataframe(
+                        raw_train_df,
+                        train_predictions[f"{self.predict_prefix}label"].values,
+                        error_fn(
+                            train_predictions[
+                                f"{self.predict_prefix}score_{self.positive_class}"
+                            ].values,
+                            raw_train_df[self.target_col].to_numpy(),
+                        ),
+                        self.target_col,
+                    )
+
+                    if "calibrate_proba" in self.step_config and hasattr(
+                        additional_fitted_args.get("original_estimator"), "predict_proba"
+                    ):
+                        from sklearn.calibration import CalibrationDisplay
+
+                        calibrated_plot = CalibrationDisplay.from_estimator(
+                            additional_fitted_args.get("original_estimator"),
+                            raw_train_df.drop(self.target_col, axis=1),
+                            raw_train_df[self.target_col],
+                            pos_label=self.positive_class,
+                        )
+                else:
+                    # compute worst examples data_frame only if positive class exists
+                    worst_examples_df = pd.DataFrame()
+
             else:
                 predicted_training_data = raw_train_df.assign(predicted_data=train_predictions)
                 worst_examples_df = BaseStep._generate_worst_examples_dataframe(
@@ -531,6 +616,7 @@ class TrainStep(BaseStep):
                 output_directory=output_directory,
                 leaderboard_df=leaderboard_df,
                 tuning_df=tuning_df,
+                calibrated_plot=calibrated_plot,
             )
             card.save_as_html(output_directory)
             for step_name in ("ingest", "split", "transform", "train"):
@@ -750,6 +836,7 @@ class TrainStep(BaseStep):
         output_directory,
         leaderboard_df=None,
         tuning_df=None,
+        calibrated_plot=None,
     ):
         import pandas as pd
         from sklearn.utils import estimator_html_repr
@@ -832,11 +919,21 @@ class TrainStep(BaseStep):
         )
 
         # Tab 5: Examples with Largest Prediction Error
-        (
-            card.add_tab("Worst Predictions", "{{ WORST_EXAMPLES_TABLE }}").add_html(
-                "WORST_EXAMPLES_TABLE", BaseCard.render_table(worst_examples_df)
+        if not worst_examples_df.empty:
+            (
+                card.add_tab("Worst Predictions", "{{ WORST_EXAMPLES_TABLE }}").add_html(
+                    "WORST_EXAMPLES_TABLE", BaseCard.render_table(worst_examples_df)
+                )
+            )
+
+        if calibrated_plot:
+            calibrated_plot_location = os.path.join(output_directory, "calibrated_plot_location")
+            calibrated_plot.figure_.savefig(calibrated_plot_location, format="png")
+            (
+                card.add_tab("Prob. Calibration", "{{ CALIBRATED_PLOT }}").add_image(
+                    "CALIBRATED_PLOT", calibrated_plot_location
+                )
             )
-        )
 
         # Tab 6: Worst predictions profile vs train profile.
         if not self.skip_data_profiling:
@@ -1017,15 +1114,18 @@ class TrainStep(BaseStep):
 
         # wrap training in objective fn
         def objective(X_train, y_train, validation_df, hyperparameter_args, on_worker=False):
+            run_name = self.tracking_config.run_name
             if on_worker:
                 client = MlflowClient()
                 parent_tags = client.get_run(parent_run_id).data.tags
                 child_run = client.create_run(
-                    _get_experiment_id(), tags={**parent_tags, "mlflow.parentRunId": parent_run_id}
+                    _get_experiment_id(),
+                    tags={**parent_tags, "mlflow.parentRunId": parent_run_id},
+                    run_name=run_name,
                 )
                 run_args = {"run_id": child_run.info.run_id}
             else:
-                run_args = {"nested": True}
+                run_args = {"run_name": run_name, "nested": True}
             with mlflow.start_run(**run_args) as tuning_run:
                 estimator_args = dict(estimator_hardcoded_params, **hyperparameter_args)
                 estimator = estimator_fn(estimator_args)
@@ -1041,10 +1141,12 @@ class TrainStep(BaseStep):
                 X_train_sampled = X_train.sample(frac=sample_fraction, random_state=42)
                 y_train_sampled = y_train.sample(frac=sample_fraction, random_state=42)
 
-                estimator.fit(X_train_sampled, y_train_sampled)
+                fitted_estimator, _ = self._fitted_estimator(
+                    estimator, X_train_sampled, y_train_sampled
+                )
 
                 logged_estimator = self._log_estimator_to_mlflow(
-                    estimator, X_train_sampled, on_worker=on_worker
+                    fitted_estimator, X_train_sampled, on_worker=on_worker
                 )
 
                 eval_result = mlflow.evaluate(
