@@ -187,8 +187,9 @@ def save_model(
                       .. code-block:: python
 
                         from mlflow.models.signature import infer_signature
+
                         train = df.drop_column("target_label")
-                        predictions = ... # compute model predictions
+                        predictions = ...  # compute model predictions
                         signature = infer_signature(train, predictions)
     :param input_example: Input example provides one or several instances of valid
                           model input. The example can be used as a hint of what data to feed the
@@ -219,14 +220,19 @@ def save_model(
         # set path to location for persistence
         sk_path_dir_1 = ...
         mlflow.sklearn.save_model(
-                sk_model, sk_path_dir_1,
-                serialization_format=mlflow.sklearn.SERIALIZATION_FORMAT_CLOUDPICKLE)
+            sk_model,
+            sk_path_dir_1,
+            serialization_format=mlflow.sklearn.SERIALIZATION_FORMAT_CLOUDPICKLE,
+        )
 
         # save the model in pickle format
         # set path to location for persistence
         sk_path_dir_2 = ...
-        mlflow.sklearn.save_model(sk_model, sk_path_dir_2,
-                                  serialization_format=mlflow.sklearn.SERIALIZATION_FORMAT_PICKLE)
+        mlflow.sklearn.save_model(
+            sk_model,
+            sk_path_dir_2,
+            serialization_format=mlflow.sklearn.SERIALIZATION_FORMAT_PICKLE,
+        )
     """
     import sklearn
 
@@ -372,8 +378,9 @@ def log_model(
                       .. code-block:: python
 
                         from mlflow.models.signature import infer_signature
+
                         train = df.drop_column("target_label")
-                        predictions = ... # compute model predictions
+                        predictions = ...  # compute model predictions
                         signature = infer_signature(train, predictions)
     :param input_example: Input example provides one or several instances of valid
                           model input. The example can be used as a hint of what data to feed the
@@ -407,7 +414,7 @@ def log_model(
         sk_model = sk_model.fit(iris.data, iris.target)
         # set the artifact_path to location where experiment artifacts will be saved
 
-        #log model params
+        # log model params
         mlflow.log_param("criterion", sk_model.criterion)
         mlflow.log_param("splitter", sk_model.splitter)
 
@@ -580,6 +587,7 @@ def load_model(model_uri, dst_path=None):
         :caption: Example
 
         import mlflow.sklearn
+
         sk_model = mlflow.sklearn.load_model("runs:/96771d893a5e46159d9f3b49bf9013e2/sk_models")
 
         # use Pandas DataFrame to make predictions
@@ -1117,6 +1125,7 @@ def autolog(
         import mlflow
         from mlflow import MlflowClient
 
+
         def fetch_logged_data(run_id):
             client = MlflowClient()
             data = client.get_run(run_id).data
@@ -1124,6 +1133,7 @@ def autolog(
             artifacts = [f.path for f in client.list_artifacts(run_id, "model")]
             return data.params, data.metrics, tags, artifacts
 
+
         # enable autologging
         mlflow.sklearn.autolog()
 
@@ -1147,10 +1157,10 @@ def autolog(
 
         pprint(metrics)
         # {'training_score': 1.0,
-           'training_mean_absolute_error': 2.220446049250313e-16,
-           'training_mean_squared_error': 1.9721522630525295e-31,
-           'training_r2_score': 1.0,
-           'training_root_mean_squared_error': 4.440892098500626e-16}
+        #  'training_mean_absolute_error': 2.220446049250313e-16,
+        #  'training_mean_squared_error': 1.9721522630525295e-31,
+        #  'training_r2_score': 1.0,
+        #  'training_root_mean_squared_error': 4.440892098500626e-16}
 
         pprint(tags)
         # {'estimator_class': 'sklearn.linear_model._base.LinearRegression',
@@ -1322,13 +1332,24 @@ def _autolog(
             registered_model_name = get_autologging_config(
                 flavor_name, "registered_model_name", None
             )
-            log_model_func(
-                self,
-                artifact_path="model",
-                signature=signature,
-                input_example=input_example,
-                registered_model_name=registered_model_name,
-            )
+            if flavor_name == mlflow.xgboost.FLAVOR_NAME:
+                model_format = get_autologging_config(flavor_name, "model_format", "xgb")
+                log_model_func(
+                    self,
+                    artifact_path="model",
+                    signature=signature,
+                    input_example=input_example,
+                    registered_model_name=registered_model_name,
+                    model_format=model_format,
+                )
+            else:
+                log_model_func(
+                    self,
+                    artifact_path="model",
+                    signature=signature,
+                    input_example=input_example,
+                    registered_model_name=registered_model_name,
+                )
         return fit_output
 
     def fit_mlflow(original, self, *args, **kwargs):
@@ -1511,7 +1532,6 @@ def _autolog(
                         child_tags=child_tags,
                     )
                 except Exception as e:
-
                     msg = (
                         "Encountered exception during creation of child runs for parameter search."
                         " Child runs may be missing. Exception: {}".format(str(e))
@@ -1524,7 +1544,6 @@ def _autolog(
                         cv_results_df, mlflow.active_run().info.run_id
                     )
                 except Exception as e:
-
                     msg = (
                         "Failed to log parameter search results as an artifact."
                         " Exception: {}".format(str(e))
