@@ -265,7 +265,6 @@ class BatchMetricsLogger:
             step = 0
 
         for key, value in metrics.items():
-
             self.data.append(Metric(key, value, int(current_timestamp * 1000), step))
 
         if self._should_flush():
@@ -420,8 +419,8 @@ def autologging_integration(name):
         wrapped_autolog.integration_name = name
 
         if name in FLAVOR_TO_MODULE_NAME_AND_VERSION_INFO_KEY:
-            wrapped_autolog.__doc__ = (
-                gen_autologging_package_version_requirements_doc(name) + wrapped_autolog.__doc__
+            wrapped_autolog.__doc__ = gen_autologging_package_version_requirements_doc(name) + (
+                wrapped_autolog.__doc__ or ""
             )
         return wrapped_autolog
 
@@ -504,6 +503,7 @@ def _get_new_training_session_class():
     ...             print(c1.should_log(), c2.should_log())
     True False
     """
+
     # NOTE: The current implementation doesn't guarantee thread-safety, but that's okay for now
     # because:
     # 1. We don't currently have any use cases for allow_children=True.
