@@ -2,13 +2,14 @@ import base64
 import json
 
 import requests
+from requests.adapters import HTTPAdapter
+from requests.exceptions import HTTPError
 import urllib3
 from contextlib import contextmanager
 from functools import lru_cache
 from packaging.version import Version
-from requests.adapters import HTTPAdapter
+
 from urllib3.util import Retry
-from requests.exceptions import HTTPError
 
 from mlflow.protos import databricks_pb2
 from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE, ENDPOINT_NOT_FOUND, ErrorCode
@@ -134,7 +135,7 @@ def http_request(
     hostname = host_creds.host
     auth_str = None
     if host_creds.username and host_creds.password:
-        basic_auth_str = ("%s:%s" % (host_creds.username, host_creds.password)).encode("utf-8")
+        basic_auth_str = ("{}:{}".format(host_creds.username, host_creds.password)).encode("utf-8")
         auth_str = "Basic " + base64.standard_b64encode(basic_auth_str).decode("utf-8")
     elif host_creds.token:
         auth_str = "Bearer %s" % host_creds.token
@@ -154,8 +155,14 @@ def http_request(
     if host_creds.client_cert_path is not None:
         kwargs["cert"] = host_creds.client_cert_path
 
+    if host_creds.aws_sigv4:
+        # will overwrite the Authorization header
+        from requests_auth_aws_sigv4 import AWSSigV4
+
+        kwargs["auth"] = AWSSigV4("execute-api")
+
     cleaned_hostname = strip_suffix(hostname, "/")
-    url = "%s%s" % (cleaned_hostname, endpoint)
+    url = f"{cleaned_hostname}{endpoint}"
     try:
         return _get_http_response_with_retries(
             method,
@@ -175,7 +182,7 @@ def http_request(
             " to a larger value."
         )
     except Exception as e:
-        raise MlflowException("API request to %s failed with exception %s" % (url, e))
+        raise MlflowException(f"API request to {url} failed with exception {e}")
 
 
 def _can_parse_as_json_object(string):
@@ -199,12 +206,12 @@ def verify_rest_response(response, endpoint):
         if _can_parse_as_json_object(response.text):
             raise RestException(json.loads(response.text))
         else:
-            base_msg = "API request to endpoint %s failed with error code %s != 200" % (
+            base_msg = "API request to endpoint {} failed with error code {} != 200".format(
                 endpoint,
                 response.status_code,
             )
             raise MlflowException(
-                "%s. Response body: '%s'" % (base_msg, response.text),
+                "{}. Response body: '{}'".format(base_msg, response.text),
                 error_code=get_error_code(response.status_code),
             )
 
@@ -215,7 +222,7 @@ def verify_rest_response(response, endpoint):
             "API request to endpoint was successful but the response body was not "
             "in a valid JSON format"
         )
-        raise MlflowException("%s. Response body: '%s'" % (base_msg, response.text))
+        raise MlflowException("{}. Response body: '{}'".format(base_msg, response.text))
 
     return response
 
@@ -232,7 +239,7 @@ def augmented_raise_for_status(response):
 
 
 def _get_path(path_prefix, endpoint_path):
-    return "{}{}".format(path_prefix, endpoint_path)
+    return f"{path_prefix}{endpoint_path}"
 
 
 def extract_api_info_for_service(service, path_prefix):
@@ -299,9 +306,9 @@ def cloud_storage_http_request(
     **kwargs,
 ):
     """
-    Performs an HTTP PUT/GET request using Python's `requests` module with automatic retry.
+    Performs an HTTP PUT/GET/PATCH request using Python's `requests` module with automatic retry.
 
-    :param method: string of 'PUT' or 'GET', specify to do http PUT or GET
+    :param method: string of 'PUT' or 'GET' or 'PATCH', specify to do http PUT or GET or PATCH
     :param url: the target URL address for the HTTP request.
     :param max_retries: maximum number of retries before throwing an exception.
     :param backoff_factor: a time factor for exponential backoff. e.g. value 5 means the HTTP
@@ -314,7 +321,7 @@ def cloud_storage_http_request(
 
     :return requests.Response object.
     """
-    if method.lower() not in ("put", "get"):
+    if method.lower() not in ("put", "get", "patch"):
         raise ValueError("Illegal http method: " + method)
     try:
         with _get_http_response_with_retries(
@@ -335,6 +342,9 @@ class MlflowHostCreds:
         If this is specified, username must also be specified.
     :param token: Token to use with Bearer authentication when talking to server.
         If provided, user/password authentication will be ignored.
+    :param aws_sigv4: If true, we will create a signature V4 to be added for any outgoing request.
+        Keys for signing the request can be passed via ENV variables,
+        or will be fetched via boto3 session.
     :param ignore_tls_verification: If true, we will not verify the server's hostname or TLS
         certificate. This is useful for certain testing situations, but should never be
         true in production.
@@ -354,6 +364,7 @@ class MlflowHostCreds:
         username=None,
         password=None,
         token=None,
+        aws_sigv4=False,
         ignore_tls_verification=False,
         client_cert_path=None,
         server_cert_path=None,
@@ -378,6 +389,7 @@ class MlflowHostCreds:
         self.username = username
         self.password = password
         self.token = token
+        self.aws_sigv4 = aws_sigv4
         self.ignore_tls_verification = ignore_tls_verification
         self.client_cert_path = client_cert_path
         self.server_cert_path = server_cert_path
